StacStackFit enum

Sizing options for Stack widget children.

Controls how non-positioned children of a Stack widget should be sized relative to the Stack's own size.

Inheritance
Available extensions

Values

loose → const StacStackFit

Children are sized to their intrinsic dimensions.

Non-positioned children can be smaller than the Stack.

expand → const StacStackFit

Children are forced to match the Stack's size.

Non-positioned children will be the same size as the Stack.

passthrough → const StacStackFit

Children inherit constraints from the Stack's parent.

The Stack's constraints are passed through to its children.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<StacStackFit>
A constant List of the values in this enum, in order of their declaration.