widgets/navigation_view/stac_navigation_view library

Classes

StacNavigationView
A Stac widget that displays one of its children based on the active index provided by a NavigationScope (established by a StacDefaultNavigationController).