StacTableCell class

A Stac model representing Flutter's TableCell widget.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

StacTableCell({StacTableCellVerticalAlignment? verticalAlignment, StacWidget? child})
Creates a StacTableCell with the given properties.
const
StacTableCell.fromJson(Map<String, dynamic> json)
Creates a StacTableCell from a JSON map.
factory

Properties

child → StacWidget?
The widget inside the table cell.
final
hashCode → int
The hash code for this object.
no setterinherited
jsonData → Map<String, dynamic>?
Raw JSON data for this widget
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the widget
no setteroverride
verticalAlignment → StacTableCellVerticalAlignment?
How the child should be aligned vertically within the cell.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this widget to a JSON map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited